# reflex-audio-capture

Cross-browser audio capture using audio-recorder-polyfill.

This component is highly experimental.

## Installation

```bash
pip install reflex-audio-capture
```

## Usage

See audio-capture-demo for example usage.